<?php

require_once 'dd.constant.php';

abstract class BaseDD {
	
	//define constant value
	const BUTTON_DESIGN_NORMAL = 'Normal';
	const BUTTON_DESIGN_COMPACT = 'Compact';
	const VOTE_URL = 'VOTE_URL'; 
	const VOTE_TITLE = 'VOTE_TITLE';
	const VOTE_BUTTON_DESIGN = 'VOTE_BUTTON_DESIGN';
	const DEFAULT_APPEND_TYPE = 'none';
	const DEFAULT_OPTION_AJAX = 'false';
	
	
    // define properties
    var $name; //name of the vote button
    var $baseURL; // vote button URL
    var $buttonDesign; //vote button design
    var $wp_options; // contains wordpress option value, in array
    
    var $finalURL; //final URL for display, after constructs
    
    var $option_append_type;
	var $option_button_design;
	var $option_button_weight;
	var $option_ajax_left_float;
	
	var $button_weight_value;
	var $normalButtonWH;
	var $compactButtonWH;
	
    /**
     * Construct the default value for digg digg 
     * @param $name name of the vote site
     * @param $baseURL URL for the vote button 
     */
    function BaseDD($name, $baseURL) {
    	$this->name = $name;
    	$this->baseURL = $baseURL;
    	$this->initWPOptions();
    }
    
    /**
     * Construct the wordpress options value
     */
    private function initWPOptions() {
    	$this->wp_options = array();
    	$this->wp_options[$this->option_append_type] = self::DEFAULT_APPEND_TYPE;
    	$this->wp_options[$this->option_button_design] = self::BUTTON_DESIGN_NORMAL;
    	$this->wp_options[$this->option_button_weight] = $this->button_weight_value;
    	$this->wp_options[$this->option_ajax_left_float] = self::DEFAULT_OPTION_AJAX;
    }
    
	/*
     * return the ajax left float option
     */
    public function get_ajax_left_float(){
    	return $this->wp_options[$this->option_ajax_left_float];
    }
    
    
	/*
     * return the button order value
     */
    public function get_button_weight(){
    	return $this->wp_options[$this->option_button_weight];
    }
    
    /*
     * return the append type value
     */
    public function get_append_type(){
    	return $this->wp_options[$this->option_append_type];
    }
    
	/*
     * return the button design value
     */
    public function get_button_design(){
    	return $this->wp_options[$this->option_button_design];
    }
    
    /**
     * Return the button design layout 
     * @param $button button design, normal or compact
     * @return button design
     */
    public function getButtonDesign($button){
    	
    	$result ='';
    	
    	if($button==self::BUTTON_DESIGN_NORMAL){
    		$result = $this->normalButtonWH;
    	}else if ($button==self::BUTTON_DESIGN_COMPACT){
    		$result = $this->compactButtonWH;
    	}else{
    		$result = $this->normalButtonWH;
    	}
    	
    	return $result;
    }
	
    /**
     * @param $url post link
     * @param $title post title
     * @param $button button design
     * 
     */
    public function construstURL($url, $title,$button){
    	$result = '';
    	
    	$result = str_replace(self::VOTE_BUTTON_DESIGN,$this->getButtonDesign($button),$this->baseURL);
    	$result = str_replace(self::VOTE_TITLE,$title,$result);
    	$result = str_replace(self::VOTE_URL,$url,$result);
    	
    	$this->finalURL = $result;
    }
    
}

//Digg.com properties and methods
class DD_Digg extends BaseDD{
	
	//constant value
	const NAME = "Digg";
	const BASEURL = "<script src='http://widgets.digg.com/buttons.js' type='text/javascript'></script><a class='DiggThisButton VOTE_BUTTON_DESIGN' href='http://digg.com/submit?url=VOTE_URL&amp;title='VOTE_TITLE'></a>";
	
	const OPTION_APPEND_TYPE = "dd_digg_appendType";
	const OPTION_BUTTON_DESIGN = "dd_digg_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_digg_button_weight";
	const NORMAL_BUTTON_WH = "DiggMedium";
	const COMPACT_BUTTON_WH = "DiggCompact";
	const DEFAULT_BUTTON_WEIGHT = "100";
	const OPTION_AJAX_LEFT_FLOAT = "dd_digg_ajax_left_float";
	
	//constructor
    public function DD_Digg() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//Reddit.com properties and methods
class DD_Reddit extends BaseDD{
	
	//constant value
	const NAME = "Reddit";
	//const BASEURL = "<iframe src='http://www.reddit.com/button_content?newwindow=1&amp;url=VOTE_URL&amp;title=VOTE_TITLE&amp;t=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	
	const BASEURL = "<script type='text/javascript'>reddit_url = VOTE_URL;reddit_title = VOTE_TITLE;reddit_newwindow='1';</script><script type='text/javascript' src='http://www.reddit.com/static/button/VOTE_BUTTON_DESIGN'></script>";

	
	const OPTION_APPEND_TYPE = "dd_reddit_appendType";
	const OPTION_BUTTON_DESIGN = "dd_reddit_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_reddit_button_weight";
	const NORMAL_BUTTON_WH = "button2.js";
	const COMPACT_BUTTON_WH = "button1.js";
	const DEFAULT_BUTTON_WEIGHT = "95";
	const OPTION_AJAX_LEFT_FLOAT = "dd_reddit_ajax_left_float";
	
	//constructor
    public function DD_Reddit() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//dzone.com properties and methods
class DD_Dzone extends BaseDD{
	
	//constant value
	const NAME = "Dzone";
	const BASEURL = "<iframe src='http://widgets.dzone.com/links/widgets/zoneit.html?url=VOTE_URL&amp;title=VOTE_TITLE&amp;t=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_dzone_appendType";
	const OPTION_BUTTON_DESIGN = "dd_dzone_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_dzone_button_weight";
	const NORMAL_BUTTON_WH = "1' height='68' width='52'";
	const COMPACT_BUTTON_WH = "2' height='18' width='120'";
	const DEFAULT_BUTTON_WEIGHT = "90";
	const OPTION_AJAX_LEFT_FLOAT = "dd_dzone_ajax_left_float";
	          
	//constructor
    public function DD_Dzone() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}


//buzz.yahoo.com properties and methods
class DD_YBuzz extends BaseDD{
	
	//constant value
	const NAME = "YBuzz";
	const BASEURL = "<script type='text/javascript'><!--yahooBuzzArticleHeadline=VOTE_TITLE;//--></script><script type='text/javascript' src='http://d.yimg.com/ds/badge2.js' badgetype='VOTE_BUTTON_DESIGN'></script>";
	const OPTION_APPEND_TYPE = "dd_ybuzz_appendType";
	const OPTION_BUTTON_DESIGN = "dd_ybuzz_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_ybuzz_button_weight";
	const NORMAL_BUTTON_WH = "square";
	const COMPACT_BUTTON_WH = "small-votes";
	const DEFAULT_BUTTON_WEIGHT = "85";
	const OPTION_AJAX_LEFT_FLOAT = "dd_ybuzz_ajax_left_float";
	      
	//constructor
    public function DD_YBuzz() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//tweetmeme.com properties and methods
class DD_Twitter extends BaseDD{
	
	//constant value
	const NAME = "Twitter";
	const BASEURL ="<iframe src='http://api.tweetmeme.com/button.js?url=VOTE_URL&amp;source=VOTE_SOURCE&amp;style=VOTE_BUTTON_DESIGN frameborder='0' scrolling='no'></iframe>";
	const OPTION_APPEND_TYPE = "dd_twitter_appendType";
	const OPTION_BUTTON_DESIGN = "dd_twitter_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_twitter_button_weight";
	const NORMAL_BUTTON_WH = "normal' height='61' width='50'";
	const COMPACT_BUTTON_WH = "compact' height='20' width='90'";
    const DEFAULT_BUTTON_WEIGHT = "80";
    const OPTION_AJAX_LEFT_FLOAT = "dd_twitter_ajax_left_float";
          
	const VOTE_SOURCE = "VOTE_SOURCE";
	
	//constructor
    public function DD_Twitter() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
        
    } 
    
    //override the base method to construct the source 
	public function construstURL($url, $source,$button){
    	$result = '';
    	
    	$realButtonLayout =$this->getButtonDesign($button);
    	$result = str_replace(parent::VOTE_BUTTON_DESIGN,$realButtonLayout,$this->baseURL);
    	$result = str_replace(self::VOTE_SOURCE,$source,$result);
    	$result = str_replace(parent::VOTE_URL,$url,$result);
    	
    	$this->finalURL = $result;
    }
    
}

//fbshare.com properties and methods
class DD_FbShare extends BaseDD{
	
	//constant value
	const NAME = "Facebook";
	const BASEURL = "<a name='fb_share' type='VOTE_BUTTON_DESIGN' share_url='VOTE_URL' href='http://www.facebook.com/sharer.php'>Share</a><script src='http://static.ak.fbcdn.net/connect.php/js/FB.Share' type='text/javascript'></script>";
	const OPTION_APPEND_TYPE = "dd_fbshare_appendType";
	const OPTION_BUTTON_DESIGN = "dd_fbshare_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_fbshare_button_weight";
	const NORMAL_BUTTON_WH = "box_count";
	const COMPACT_BUTTON_WH = "button_count";
	const DEFAULT_BUTTON_WEIGHT = "75";
	const OPTION_AJAX_LEFT_FLOAT = "dd_fbshare_ajax_left_float";
	
	//constructor
    public function DD_FbShare() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}


//polladium.com properties and methods
class DD_Polladium extends BaseDD{
	
	//constant value
	const NAME = "Polladium";
	const BASEURL = "<script type='text/javascript' src='http://www.polladium.com/web_services/poll-this/poll-this.js?t=VOTE_TITLE&amp;u=VOTE_URL&amp;type=VOTE_BUTTON_DESIGN'></script>";
	const OPTION_APPEND_TYPE = "dd_polladium_appendType";
	const OPTION_BUTTON_DESIGN = "dd_polladium_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_polladium_button_weight";
	const NORMAL_BUTTON_WH = "normal";
	const COMPACT_BUTTON_WH = "compact";
	const DEFAULT_BUTTON_WEIGHT = "70";
	const OPTION_AJAX_LEFT_FLOAT = "dd_polladium_ajax_left_float";
	
	//constructor
    public function DD_Polladium() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}

//stumbleupon.com properties and methods
class DD_StumbleUpon extends BaseDD{
	
	//constant value
	const NAME = "Stumbleupon";
	const BASEURL = "<script src=\"http://www.stumbleupon.com/hostedbadge.php?s=VOTE_BUTTON_DESIGN&amp;r=VOTE_URL\"></script>";
	const OPTION_APPEND_TYPE = "dd_stumbleupon_appendType";
	const OPTION_BUTTON_DESIGN = "dd_stumbleupon_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_stumbleupon_button_weight";
	const NORMAL_BUTTON_WH = "5";
	const COMPACT_BUTTON_WH = "1";
	const DEFAULT_BUTTON_WEIGHT = "65";
	const OPTION_AJAX_LEFT_FLOAT = "dd_stumbleupon_ajax_left_float";
	
	//constructor
    public function DD_StumbleUpon() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}


//delicious.com properties and methods
class DD_Delicious extends BaseDD{
	
	//constant value
	const NAME = "Delicious";
	const BASEURL = "<a href='http://delicious.com/save' onclick=\"window.open('http://delicious.com/save?v=5&amp;noui&amp;jump=close&amp;url='+encodeURIComponent('VOTE_URL')+'&amp;title='+encodeURIComponent('VOTE_TITLE'),'delicious', 'toolbar=no,width=550,height=550'); return false;\">VOTE_BUTTON_DESIGN</a>";
	const OPTION_APPEND_TYPE = "dd_delicious_appendType";
	const OPTION_BUTTON_DESIGN = "dd_delicious_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_delicious_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "60";
	const OPTION_AJAX_LEFT_FLOAT = "dd_delicious_ajax_left_float";

	//constructor
    public function DD_Delicious() {
    	
    	$normalbutton = "<img src='" . DD_PLUGPATH . "image/delicious.png' width='54' height='54' alt='Delicious' />";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $normalbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
}

//sphinn.com properties and methods
class DD_Sphinn extends BaseDD{
	
	//constant value
	const NAME = "Sphinn";
	const BASEURL ="<script type='text/javascript'> submit_url = \"VOTE_URL\"; </script> <script type='text/javascript' src='http://sphinn.com/evb/button.php'></script>";
	const OPTION_APPEND_TYPE = "dd_sphinn_appendType";
	const OPTION_BUTTON_DESIGN = "dd_sphinn_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_sphinn_button_weight";
	const NORMAL_BUTTON_WH = "large";
	const COMPACT_BUTTON_WH = "small";
	const DEFAULT_BUTTON_WEIGHT = "55";
	const OPTION_AJAX_LEFT_FLOAT = "dd_sphinn_ajax_left_float";
	
	//constructor
    public function DD_Sphinn() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//post comments properties and methods
class DD_Comments extends BaseDD{
	
	//#comments
	//constant value
	const NAME = "Comments";
	const BASEURL = "<div id=\"dd_comments\"><a class=\"clcount\" href=VOTE_URL><span class=\"ctotal\">COMMENTS_COUNT</span><br /><span class=\"cmsg\">Comments</span></a><a class=\"clink\" href=VOTE_URL></a></div>";
	
	const OPTION_APPEND_TYPE = "dd_comments_appendType";
	const OPTION_BUTTON_DESIGN = "dd_comments_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_comments_button_weight";
	const DEFAULT_BUTTON_WEIGHT = "50";
	
	const COMMENTS_COUNT = "COMMENTS_COUNT";
	const COMMENTS_FLOW = "COMMENTS_FLOW";
	const COMMENTS_DETAIL_ID = "#comments";
	const COMMENTS_RESPONSE_ID = "#respond";
	const OPTION_AJAX_LEFT_FLOAT = "dd_comments_ajax_left_float";

	//constructor
    public function DD_Comments() {
    	
    	$normalbutton = "";
		
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = $normalbutton;
		$this->compactButtonWH = $normalbutton;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    }     
    
	//override the base method to construct the source 
	public function construstURL($url,$count){
    	$result = '';
    	
    	if($count!='0'){
    		$url = $url . self::COMMENTS_DETAIL_ID;
    	}else{
    		$url = $url . self::COMMENTS_RESPONSE_ID;
    	}
    	
    	$result = str_replace(self::VOTE_URL,$url,$this->baseURL);
    	$result = str_replace(self::COMMENTS_COUNT,$count,$result);
    	
    	$this->finalURL = $result;
    }
    
}

//Google Buzz properties and methods
class DD_GBuzz extends BaseDD{
	
	//constant value
	const NAME = "Google buzz";
	//const BASEURL = "<script type='text/javascript'>var __external_use_page_url = \"VOTE_URL\";var __buzrr_style=\"VOTE_BUTTON_DESIGN\";</script><script src='http://cdn.buzrr.com/js/button.js' type='text/javascript'> </script>";
	//const BASEURL = "<iframe frameborder='0' scrolling='no' src='http://buzrr.com/button.php?url=VOTE_URL&amp;style=VOTE_BUTTON_DESIGN></iframe>";
	
	const BASEURL = "<a title=\"Post on Google Buzz\" class=\"google-buzz-button\" href=\"http://www.google.com/buzz/post\" data-button-style=\"VOTE_BUTTON_DESIGN\" data-url=\"VOTE_URL\"></a><script type=\"text/javascript\" src=\"http://www.google.com/buzz/api/button.js\"></script>";

	const OPTION_APPEND_TYPE = "dd_gbuzz_appendType";
	const OPTION_BUTTON_DESIGN = "dd_gbuzz_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_gbuzz_button_weight";
	const NORMAL_BUTTON_WH = "normal-count";
	const COMPACT_BUTTON_WH = "small-count";
	const DEFAULT_BUTTON_WEIGHT = "45";
	const OPTION_AJAX_LEFT_FLOAT = "dd_gbuzz_ajax_left_float";

	//constructor
    public function DD_GBuzz() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
        
    }     
   
}

//designbump.com properties and methods
class DD_DesignBump extends BaseDD{
	
	//constant value
	const NAME = "DesignBump";
	const BASEURL = "<script type='text/javascript'>url_site='VOTE_URL'; </script> <script src='http://designbump.com/sites/all/modules/drigg_external/js/button.js' type='text/javascript'></script>";
	const OPTION_APPEND_TYPE = "dd_designbump_appendType";
	const OPTION_BUTTON_DESIGN = "dd_designbump_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_designbump_button_weight";
	const NORMAL_BUTTON_WH = "";
	const COMPACT_BUTTON_WH = "";
	const DEFAULT_BUTTON_WEIGHT = "40";
	const OPTION_AJAX_LEFT_FLOAT = "dd_designbump_ajax_left_float";
	
	//constructor
    public function DD_DesignBump() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//designfloat.com properties and methods
class DD_DesignFloat extends BaseDD{

	//constant value
	const NAME = "DesignFloat";	
	const BASEURL = "<script type='text/javascript'>submit_url = 'VOTE_URL';</script><script type='text/javascript' src='http://www.designfloat.com/VOTE_BUTTON_DESIGN/button.php'></script>";
	const OPTION_APPEND_TYPE = "dd_designfloat_appendType";
	const OPTION_BUTTON_DESIGN = "dd_designfloat_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_designfloat_button_weight";
	const NORMAL_BUTTON_WH = "evb2";
	const COMPACT_BUTTON_WH = "evb";
	const DEFAULT_BUTTON_WEIGHT = "35";
	const OPTION_AJAX_LEFT_FLOAT = "dd_designfloat_ajax_left_float";

	//constructor
    public function DD_DesignFloat() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//thewebblend.com properties and methods
class DD_WebBlend extends BaseDD{

	//constant value
	const NAME = "TheWebBlend";	
	const BASEURL = "<script type='text/javascript'>url_site='VOTE_URL';</script><script src='http://thewebblend.com/sites/all/modules/drigg_external/js/button.js' type='text/javascript'></script>";
	const OPTION_APPEND_TYPE = "dd_webblend_appendType";
	const OPTION_BUTTON_DESIGN = "dd_webblend_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_webblend_button_weight";
	const NORMAL_BUTTON_WH = "";
	const COMPACT_BUTTON_WH = "";
	const DEFAULT_BUTTON_WEIGHT = "30";
	const OPTION_AJAX_LEFT_FLOAT = "dd_webblend_ajax_left_float";

	//constructor
    public function DD_WebBlend() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}

//blogengage.com properties and methods
class DD_BlogEngage extends BaseDD{

	//constant value
	const NAME = "BogEngage";	
	
	const BASEURL = "<script type='text/javascript'>submit_url = 'VOTE_URL';</script><script src='http://blogengage.com/evb/VOTE_BUTTON_DESIGN'></script>";
  
	const OPTION_APPEND_TYPE = "dd_blogengage_appendType";
	const OPTION_BUTTON_DESIGN = "dd_blogengage_buttonDesign";
	const OPTION_BUTTON_WEIGHT = "dd_blogengage_button_weight";
	const NORMAL_BUTTON_WH = "button4.php";
	const COMPACT_BUTTON_WH = "button2.php";
	const DEFAULT_BUTTON_WEIGHT = "25";
	const OPTION_AJAX_LEFT_FLOAT = "dd_blogengage_ajax_left_float";

	//constructor
    public function DD_BlogEngage() {
    	
    	//wordpress option value
		$this->option_append_type = self::OPTION_APPEND_TYPE;
		$this->option_button_design = self::OPTION_BUTTON_DESIGN;
		$this->option_button_weight = self::OPTION_BUTTON_WEIGHT;
		$this->normalButtonWH = self::NORMAL_BUTTON_WH;
		$this->compactButtonWH = self::COMPACT_BUTTON_WH;
		$this->button_weight_value = self::DEFAULT_BUTTON_WEIGHT;
		$this->option_ajax_left_float = self::OPTION_AJAX_LEFT_FLOAT;
	
        parent::BaseDD(self::NAME, self::BASEURL);
    } 
    
}  
?>